import { CustomResource, RemovalPolicy } from 'aws-cdk-lib';
import { ISecurityGroup, IVpc } from 'aws-cdk-lib/aws-ec2';
import { IPrincipal, IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { CfnCluster, CfnConfiguration } from 'aws-cdk-lib/aws-msk';
import { Construct } from 'constructs';
import { MskProvisionedProps } from './msk-provisioned-props';
import { KafkaVersion, Acl, Authentication, MskTopic } from './msk-utils';
import { TrackedConstruct } from '../../../utils';
/**
 * A construct to create an MSK Provisioned cluster
 * @see https://awslabs.github.io/data-solutions-framework-on-aws/
 *
 * @example
 *
 * const msk = new dsf.streaming.MskProvisioned(this, 'cluster');
 *
 */
export declare class MskProvisioned extends TrackedConstruct {
    static readonly MSK_DEFAULT_VERSION: KafkaVersion;
    static createClusterConfiguration(scope: Construct, id: string, name: string, serverPropertiesFilePath: string, kafkaVersions?: KafkaVersion[], configurationDescription?: string, latestRevision?: CfnConfiguration.LatestRevisionProperty): CfnConfiguration;
    /**
     * The MSK cluster created by the construct
     */
    readonly cluster: CfnCluster;
    /**
     * The VPC where the MSK cluster is deployed
     */
    readonly vpc: IVpc;
    /**
     * The KMS CMK key for encrypting data within the cluster
     */
    readonly encryptionAtRestKey: IKey;
    /**
     * The Lambda function responsible for updating Zookeeper
     */
    readonly updateZookepeerFunction: IFunction;
    /**
     * The CloudWatch Log Group used by the Lambda responsible for updating Zookeeper
     */
    readonly updateZookepeerLogGroup: ILogGroup;
    /**
     * The IAM Role used by the Lambda responsible for updating Zookeeper
     */
    readonly updateZookepeerRole: IRole;
    /**
     * THe Security Group associated to the Lambda responsible for updating Zookeeper
     */
    readonly updateZookepeerSecurityGroup: ISecurityGroup;
    /**
     * The CloudWatch Log Group used by the Lambda responsible for applying MSK configuration
     */
    readonly applyConfigurationLogGroup?: ILogGroup;
    /**
     * The IAM Role used by the Lambda responsible for applying MSK configuration
     */
    readonly applyConfigurationRole?: IRole;
    /**
     * The Security Group used by the Lambda responsible for applying MSK configuration
     */
    readonly applyConfigurationSecurityGroup?: ISecurityGroup[];
    /**
     * The Lambda function responsible for applying MSK configuration
     */
    readonly applyConfigurationFunction?: IFunction;
    /**
     * The IAM Role used by the Lambda responsible for updating MSK Connectivity
     */
    readonly updateConnectivityRole?: IRole;
    /**
     * The CloudWatch Log Group used by the Lambda responsible for updating MSK Connectivity
     */
    readonly updateConnectivityLogGroup?: ILogGroup;
    /**
     * The Lambda function responsible for updating MSK Connectivity
     */
    readonly updateConnectivityFunction?: IFunction;
    /**
     * The Security Group used by the Lambda responsible for updating MSK Connectivity
     */
    readonly updateConnectivitySecurityGroup?: ISecurityGroup[];
    /**
     * The MSK cluster configuration
     */
    readonly clusterConfiguration?: CfnConfiguration;
    /**
     * The security group associated with the MSK brokers
     */
    readonly brokerSecurityGroup?: ISecurityGroup;
    /**
     * The CloudWatch log group associated with brokers activity
     */
    readonly brokerLogGroup?: ILogGroup;
    /**
     * The IAM role used by the Lambda responsible for CRUD operations via IAM authentication
     */
    readonly iamCrudAdminRole?: IRole;
    /**
     * The CloudWatch Log Group used by the Lambda responsible for CRUD operations via IAM authentication
     */
    readonly iamCrudAdminLogGroup?: ILogGroup;
    /**
     * The Lambda function responsible for CRUD operations via IAM authentication
     */
    readonly iamCrudAdminFunction?: IFunction;
    /**
     * The Security Group used by the Lambda responsible for CRUD operations via IAM authentication
     */
    readonly iamCrudAdminSecurityGroup?: ISecurityGroup[];
    /**
     * The IAM role used by the Lambda responsible for CRUD operations via mTLS authentication
     */
    readonly inClusterAclRole?: IRole;
    /**
     * The CloudWatch Log Group used by the Lambda responsible for CRUD operations via mTLS authentication
     */
    readonly inClusterAclLogGroup?: ILogGroup;
    /**
     * The Lambda function responsible for CRUD operations via mTLS authentication
     */
    readonly inClusterAclFunction?: IFunction;
    /**
     * The Security Group used by the Lambda responsible for CRUD operations via mTLS authentication
     */
    readonly inClusterAclSecurityGroup?: ISecurityGroup[];
    private readonly removalPolicy;
    private readonly region;
    private readonly mskBrokerinstanceType;
    private readonly subnetSelectionIds;
    private readonly connections;
    private readonly defaultNumberOfBrokerNodes;
    private readonly numberOfBrokerNodes;
    private readonly inClusterAcl;
    private readonly iamAcl;
    private readonly crPrincipal?;
    private aclOperationCr?;
    private aclDeleteTopic?;
    private aclCreateTopic?;
    private readonly deploymentClusterVersion;
    private readonly kafkaApi;
    private readonly clusterVpcConnectivity?;
    private readonly placeClusterHandlerInVpc?;
    /**
     * Constructs a new instance of the EmrEksCluster construct.
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param {MskServerlessProps} props
     */
    constructor(scope: Construct, id: string, props?: MskProvisionedProps);
    /**
     * Creates a topic in the Msk Cluster
     * @param {string} id the CDK id for Topic
     * @param {Acl} aclDefinition the Kafka Acl definition
     * @param {RemovalPolicy} removalPolicy Wether to keep the ACL or delete it when removing the resource from the Stack {@default RemovalPolicy.RETAIN}
     * @returns {CustomResource} The MskAcl custom resource created
     */
    setAcl(id: string, aclDefinition: Acl, removalPolicy?: RemovalPolicy): CustomResource;
    /**
     * Creates a topic in the Msk Cluster
     *
     * @param {string} id the CDK id for Topic
     * @param {Authentication} clientAuthentication The client authentication to use when creating the Topic
     * @param {MskTopic} topicDefinition the Kafka topic definition
     * @param {RemovalPolicy} removalPolicy Wether to keep the topic or delete it when removing the resource from the Stack {@default RemovalPolicy.RETAIN}
     * @param {boolean} waitForLeaders If this is true it will wait until metadata for the new topics doesn't throw LEADER_NOT_AVAILABLE
     * @param {number} timeout The time in ms to wait for a topic to be completely created on the controller node @default 5000
     * @returns {CustomResource} The MskTopic custom resource created
     */
    setTopic(id: string, clientAuthentication: Authentication, topicDefinition: MskTopic, removalPolicy?: RemovalPolicy, waitForLeaders?: boolean, timeout?: number): CustomResource;
    /**
     * Grant a principal to produce data to a topic
     * @param {string} id the CDK resource id
     * @param {string} topicName the topic to which the principal can produce data
     * @param {Authentitcation} clientAuthentication The client authentication to use when grant on resource
     * @param {IPrincipal | string } principal the IAM principal to grand the produce to
     * @param {string} host the host to which the principal can produce data.
     * @param {RemovalPolicy} removalPolicy
     * @returns When MTLS is used as authentication an ACL is created using the MskAcl Custom resource to write in the topic is created and returned,
     *          you can use it to add dependency on it.
     */
    grantProduce(id: string, topicName: string, clientAuthentication: Authentication, principal: IPrincipal | string, host?: string, removalPolicy?: RemovalPolicy): CustomResource | undefined;
    /**
     * Grant a principal the right to consume data from a topic
     *
     * @param {string} id the CDK resource id
     * @param {string} topicName the topic to which the principal can produce data
     * @param {Authentitcation} clientAuthentication The client authentication to use when grant on resource
     * @param {IPrincipal | string } principal the IAM principal to grand the produce to
     * @param {string} host the host to which the principal can produce data.
     * @param {RemovalPolicy} removalPolicy
     * @returns When MTLS is used as authentication, an ACL is created using the MskAcl Custom resource to read from the topic is created and returned,
     *          you can use it to add dependency on it.
     */
    grantConsume(id: string, topicName: string, clientAuthentication: Authentication, principal: IPrincipal | string, host?: string, removalPolicy?: RemovalPolicy): CustomResource | undefined;
    putClusterPolicy(policy: string, id: string, currentVersion?: string): void;
    deleteClusterPolicy(): void;
    private setAcls;
    /**
     * Method to get bootstrap broker connection string based on the authentication mode
     * @param authentication the authentication mode
     * @returns the MSK bootstrap URL
     */
    getBootstrapBrokers(authentication: Authentication): string;
}
